==> tool-sql-1.1.10-sources.jar: io/ciera/tool/sql/ooaofooa/interaction/impl/ClassInstanceParticipantSetImpl.java <==
package io.ciera.tool.sql.ooaofooa.interaction.impl;


import io.ciera.runtime.summit.classes.InstanceSet;
import io.ciera.runtime.summit.exceptions.XtumlException;
import io.ciera.runtime.summit.types.UniqueId;
import io.ciera.tool.sql.ooaofooa.interaction.ClassInstanceParticipant;
import io.ciera.tool.sql.ooaofooa.interaction.ClassInstanceParticipantSet;
import io.ciera.tool.sql.ooaofooa.interaction.InstanceAttributeValueSet;
import io.ciera.tool.sql.ooaofooa.interaction.InteractionParticipantSet;
import io.ciera.tool.sql.ooaofooa.interaction.impl.InstanceAttributeValueSetImpl;
import io.ciera.tool.sql.ooaofooa.interaction.impl.InteractionParticipantSetImpl;
import io.ciera.tool.sql.ooaofooa.subsystem.ModelClassSet;
import io.ciera.tool.sql.ooaofooa.subsystem.impl.ModelClassSetImpl;

import java.util.Arrays;
import java.util.List;


public class ClassInstanceParticipantSetImpl extends InstanceSet<ClassInstanceParticipantSet,ClassInstanceParticipant> implements ClassInstanceParticipantSet {

    // attributes
    @Override
    public void setIsFormal( boolean m_isFormal ) throws XtumlException {
        for ( ClassInstanceParticipant classinstanceparticipant : this ) classinstanceparticipant.setIsFormal( m_isFormal );
    }
    @Override
    public void setLabel( String m_Label ) throws XtumlException {
        for ( ClassInstanceParticipant classinstanceparticipant : this ) classinstanceparticipant.setLabel( m_Label );
    }
    @Override
    public void setPart_ID( UniqueId ref_Part_ID ) throws XtumlException {
        for ( ClassInstanceParticipant classinstanceparticipant : this ) classinstanceparticipant.setPart_ID( ref_Part_ID );
    }
    @Override
    public void setName( String m_Name ) throws XtumlException {
        for ( ClassInstanceParticipant classinstanceparticipant : this ) classinstanceparticipant.setName( m_Name );
    }
    @Override
    public void setInformalClassName( String m_InformalClassName ) throws XtumlException {
        for ( ClassInstanceParticipant classinstanceparticipant : this ) classinstanceparticipant.setInformalClassName( m_InformalClassName );
    }
    @Override
    public void setObj_ID( UniqueId ref_Obj_ID ) throws XtumlException {
        for ( ClassInstanceParticipant classinstanceparticipant : this ) classinstanceparticipant.setObj_ID( ref_Obj_ID );
    }
    @Override
    public void setDescrip( String m_Descrip ) throws XtumlException {
        for ( ClassInstanceParticipant classinstanceparticipant : this ) classinstanceparticipant.setDescrip( m_Descrip );
    }


    // selections
    @Override
    public InteractionParticipantSet R930_is_a_InteractionParticipant() throws XtumlException {
        InteractionParticipantSet interactionparticipantset = new InteractionParticipantSetImpl();
        for ( ClassInstanceParticipant classinstanceparticipant : this ) interactionparticipantset.add( classinstanceparticipant.R930_is_a_InteractionParticipant() );
        return interactionparticipantset;
    }
    @Override
    public ModelClassSet R934_represents_ModelClass() throws XtumlException {
        ModelClassSet modelclassset = new ModelClassSetImpl();
        for ( ClassInstanceParticipant classinstanceparticipant : this ) modelclassset.add( classinstanceparticipant.R934_represents_ModelClass() );
        return modelclassset;
    }
    @Override
    public InstanceAttributeValueSet R936_contains_informal_InstanceAttributeValue() throws XtumlException {
        InstanceAttributeValueSet instanceattributevalueset = new InstanceAttributeValueSetImpl();
        for ( ClassInstanceParticipant classinstanceparticipant : this ) instanceattributevalueset.addAll( classinstanceparticipant.R936_contains_informal_InstanceAttributeValue() );
        return instanceattributevalueset;
    }
    @Override
    public InstanceAttributeValueSet R937_contains_formal_InstanceAttributeValue() throws XtumlException {
        InstanceAttributeValueSet instanceattributevalueset = new InstanceAttributeValueSetImpl();
        for ( ClassInstanceParticipant classinstanceparticipant : this ) instanceattributevalueset.addAll( classinstanceparticipant.R937_contains_formal_InstanceAttributeValue() );
        return instanceattributevalueset;
    }


    @Override
    public ClassInstanceParticipant nullElement() {
        return ClassInstanceParticipantImpl.EMPTY_CLASSINSTANCEPARTICIPANT;
    }

    @Override
    public ClassInstanceParticipantSet emptySet() {
      return new ClassInstanceParticipantSetImpl();
    }

    @Override
    public ClassInstanceParticipantSet value() {
        return this;
    }

    @Override
    public List<ClassInstanceParticipant> elements() {
        ClassInstanceParticipant[] elements = toArray(new ClassInstanceParticipant[0]);
        Arrays.sort(elements, (a, b) -> {
            try {
                return a.getName().compareTo(b.getName());
            } catch (XtumlException e) { return 0; }
        });
        return Arrays.asList(elements);
    }

}

==> tool-sql-1.1.11-sources.jar: io/ciera/tool/sql/ooaofooa/interaction/impl/ClassInstanceParticipantSetImpl.java <==
package io.ciera.tool.sql.ooaofooa.interaction.impl;


import io.ciera.runtime.summit.classes.InstanceSet;
import io.ciera.runtime.summit.exceptions.XtumlException;
import io.ciera.runtime.summit.types.UniqueId;
import io.ciera.tool.sql.ooaofooa.interaction.ClassInstanceParticipant;
import io.ciera.tool.sql.ooaofooa.interaction.ClassInstanceParticipantSet;
import io.ciera.tool.sql.ooaofooa.interaction.InstanceAttributeValueSet;
import io.ciera.tool.sql.ooaofooa.interaction.InteractionParticipantSet;
import io.ciera.tool.sql.ooaofooa.interaction.impl.InstanceAttributeValueSetImpl;
import io.ciera.tool.sql.ooaofooa.interaction.impl.InteractionParticipantSetImpl;
import io.ciera.tool.sql.ooaofooa.subsystem.ModelClassSet;
import io.ciera.tool.sql.ooaofooa.subsystem.impl.ModelClassSetImpl;

import java.util.Arrays;
import java.util.Comparator;
import java.util.List;


public class ClassInstanceParticipantSetImpl extends InstanceSet<ClassInstanceParticipantSet,ClassInstanceParticipant> implements ClassInstanceParticipantSet {

    public ClassInstanceParticipantSetImpl() {
    }

    public ClassInstanceParticipantSetImpl(Comparator<? super ClassInstanceParticipant> comp) {
        super(comp);
    }

    // attributes
    @Override
    public void setDescrip( String m_Descrip ) throws XtumlException {
        for ( ClassInstanceParticipant classinstanceparticipant : this ) classinstanceparticipant.setDescrip( m_Descrip );
    }
    @Override
    public void setIsFormal( boolean m_isFormal ) throws XtumlException {
        for ( ClassInstanceParticipant classinstanceparticipant : this ) classinstanceparticipant.setIsFormal( m_isFormal );
    }
    @Override
    public void setName( String m_Name ) throws XtumlException {
        for ( ClassInstanceParticipant classinstanceparticipant : this ) classinstanceparticipant.setName( m_Name );
    }
    @Override
    public void setObj_ID( UniqueId ref_Obj_ID ) throws XtumlException {
        for ( ClassInstanceParticipant classinstanceparticipant : this ) classinstanceparticipant.setObj_ID( ref_Obj_ID );
    }
    @Override
    public void setLabel( String m_Label ) throws XtumlException {
        for ( ClassInstanceParticipant classinstanceparticipant : this ) classinstanceparticipant.setLabel( m_Label );
    }
    @Override
    public void setPart_ID( UniqueId ref_Part_ID ) throws XtumlException {
        for ( ClassInstanceParticipant classinstanceparticipant : this ) classinstanceparticipant.setPart_ID( ref_Part_ID );
    }
    @Override
    public void setInformalClassName( String m_InformalClassName ) throws XtumlException {
        for ( ClassInstanceParticipant classinstanceparticipant : this ) classinstanceparticipant.setInformalClassName( m_InformalClassName );
    }


    // selections
    @Override
    public InteractionParticipantSet R930_is_a_InteractionParticipant() throws XtumlException {
        InteractionParticipantSet interactionparticipantset = new InteractionParticipantSetImpl();
        for ( ClassInstanceParticipant classinstanceparticipant : this ) interactionparticipantset.add( classinstanceparticipant.R930_is_a_InteractionParticipant() );
        return interactionparticipantset;
    }
    @Override
    public ModelClassSet R934_represents_ModelClass() throws XtumlException {
        ModelClassSet modelclassset = new ModelClassSetImpl();
        for ( ClassInstanceParticipant classinstanceparticipant : this ) modelclassset.add( classinstanceparticipant.R934_represents_ModelClass() );
        return modelclassset;
    }
    @Override
    public InstanceAttributeValueSet R936_contains_informal_InstanceAttributeValue() throws XtumlException {
        InstanceAttributeValueSet instanceattributevalueset = new InstanceAttributeValueSetImpl();
        for ( ClassInstanceParticipant classinstanceparticipant : this ) instanceattributevalueset.addAll( classinstanceparticipant.R936_contains_informal_InstanceAttributeValue() );
        return instanceattributevalueset;
    }
    @Override
    public InstanceAttributeValueSet R937_contains_formal_InstanceAttributeValue() throws XtumlException {
        InstanceAttributeValueSet instanceattributevalueset = new InstanceAttributeValueSetImpl();
        for ( ClassInstanceParticipant classinstanceparticipant : this ) instanceattributevalueset.addAll( classinstanceparticipant.R937_contains_formal_InstanceAttributeValue() );
        return instanceattributevalueset;
    }


    @Override
    public ClassInstanceParticipant nullElement() {
        return ClassInstanceParticipantImpl.EMPTY_CLASSINSTANCEPARTICIPANT;
    }

    @Override
    public ClassInstanceParticipantSet emptySet() {
      return new ClassInstanceParticipantSetImpl();
    }

    @Override
    public ClassInstanceParticipantSet emptySet(Comparator<? super ClassInstanceParticipant> comp) {
      return new ClassInstanceParticipantSetImpl(comp);
    }

    @Override
    public ClassInstanceParticipantSet value() {
        return this;
    }

    @Override
    public List<ClassInstanceParticipant> elements() {
        ClassInstanceParticipant[] elements = toArray(new ClassInstanceParticipant[0]);
        Arrays.sort(elements, (a, b) -> {
            try {
                return a.getName().compareTo(b.getName());
            } catch (XtumlException e) { return 0; }
        });
        return Arrays.asList(elements);
    }

}
